Get the time of each step in a wind_series
wind_times.RdReturns the time of each step of a wind_series, parsed from its layer names (like
"u 2000-01-01 06:00:00", as written by ncar_download()) or, if the names hold no times,
from the times set with terra::time().
See also
subset_series() to select time steps.
Examples
series <- windscape_example("wind_series")
head(wind_times(series))
#> [1] "2000-01-01 00:00:00 UTC" "2000-01-01 06:00:00 UTC"
#> [3] "2000-01-01 12:00:00 UTC" "2000-01-01 18:00:00 UTC"
#> [5] "2000-01-15 00:00:00 UTC" "2000-01-15 06:00:00 UTC"